@@ -1,6 +1,6 @@
 use crate::ChopError::*;
 use args::RunConfig;
-use chopstick::digits;
+use chopstick::{digits, sufficient_disk_space};
 pub use error::*;
 pub use lib::*;
 use std::fs::OpenOptions;
@@ -21,6 +21,22 @@ fn main() {
 fn _main() -> Result<()> {
     let config = RunConfig::new()?;
 
+    // Check if there is sufficient disk space available
+    let space_needed = if !config.retain {
+        config.split.part_size
+    } else {
+        fs::metadata(&config.path)?.len()
+    };
+    match sufficient_disk_space(&config.path, space_needed) {
+        Ok(true) => {
+            if config.verbose {
+                eprintln!("Enough disk space available for operation");
+            }
+        }
+        Ok(false) => return Err(InsufficientDiskSpace),
+        Err(warn) => eprintln!("WARNING: {}", warn),
+    }
+
     // Cast is saturating if part_size > usize::MAX
     let mut buffer = Vec::with_capacity(config.split.part_size as usize);
     let mut handle = OpenOptions::new()
@@ -49,19 +65,24 @@ fn _main() -> Result<()> {
                 .expect("Arithmetic error, seek outside of file");
 
             // Step 2: Create part file
-            let mut part_file = OpenOptions::new()
-                .write(true)
-                .create_new(true)
-                .open(&part_path)
-                .map_err(|err| {
-                    use std::io::ErrorKind::*;
-                    match err.kind() {
-                        AlreadyExists => {
-                            PartFileAlreadyExists(part_path.clone())
+            let part_file = if !config.dry_run {
+                OpenOptions::new()
+                    .write(true)
+                    .create_new(true)
+                    .open(&part_path)
+                    .map_err(|err| {
+                        use std::io::ErrorKind::*;
+                        match err.kind() {
+                            AlreadyExists => {
+                                PartFileAlreadyExists(part_path.clone())
+                            }
+                            _ => err.into(),
                         }
-                        _ => err.into(),
-                    }
-                })?;
+                    })?
+                    .into()
+            } else {
+                None
+            };
 
             if config.verbose {
                 eprintln!(
@@ -71,26 +92,30 @@ fn _main() -> Result<()> {
             }
 
             // Step 3: read to end of source file into the buffer
-            handle.read_to_end(&mut buffer).map_err(FailedToReadPart)?;
-
+            if !config.dry_run {
+                handle.read_to_end(&mut buffer).map_err(FailedToReadPart)?;
+            }
             if config.verbose {
                 eprintln!("Read {} bytes into buffer", buffer.len());
             }
 
             // Step 4: write buffer to part file, then clear buffer
-            part_file
-                .write_all(&buffer)
-                .map_err(|err| FailedToWritePart(part_path.clone(), err))?;
-            buffer.clear();
-
+            if !config.dry_run {
+                part_file
+                    .unwrap()
+                    .write_all(&buffer)
+                    .map_err(|err| FailedToWritePart(part_path.clone(), err))?;
+                buffer.clear();
+            }
             if config.verbose {
                 eprintln!("Wrote buffer to part file");
             }
 
             // Step 5: truncate source file
             if !config.retain {
-                handle.set_len(byte_offset).map_err(FailedToTruncate)?;
-
+                if !config.dry_run {
+                    handle.set_len(byte_offset).map_err(FailedToTruncate)?;
+                }
                 if config.verbose {
                     eprintln!("Truncated original file");
                 }
@@ -103,14 +128,15 @@ fn _main() -> Result<()> {
     // soon-to-be deleted file
     mem::drop(handle);
     if !config.retain {
-        fs::remove_file(&config.path).map_err(FailedToDeleteOriginal)?;
-
+        if !config.dry_run {
+            fs::remove_file(&config.path).map_err(FailedToDeleteOriginal)?;
+        }
         if config.verbose {
             eprintln!("Deleted original file");
         }
     }
 
-    if config.verbose {
+    if config.verbose && !config.dry_run {
         eprintln!("Finished without error!");
     }
 
