@@ -15,6 +15,7 @@ pub struct RunConfig {
     pub part_paths: Vec<PathBuf>,
     pub retain: bool,
     pub verbose: bool,
+    pub dry_run: bool,
 }
 
 impl RunConfig {
@@ -43,6 +44,13 @@ impl RunConfig {
                     .long("verbose")
                     .help("Makes stick tell you what it's doing"),
             )
+            .arg(
+                Arg::new("dry-run")
+                    .long("dry-run")
+                    .visible_alias("dry")
+                    .help("Don't actually do anything, just tell me about it")
+                    .long_help("Don't actually do anything, just tell me about it (implies --verbose)"),
+            )
             .arg(
                 Arg::new("file_name")
                     .help("The file to reconstruct")
@@ -59,7 +67,8 @@ impl RunConfig {
 
     fn process_matches(clap_matches: &ArgMatches) -> Result<Self> {
         let retain = clap_matches.is_present("retain");
-        let verbose = clap_matches.is_present("verbose");
+        let dry_run = clap_matches.is_present("dry-run");
+        let verbose = dry_run || clap_matches.is_present("verbose");
 
         // Unwrap is assured by "file_name" being a required argument taking
         // a value
@@ -82,9 +91,9 @@ impl RunConfig {
 
         if discovered_paths.is_empty() {
             Err(NoParts)
-        // Check extensions indicate a complete set of parts
-        // i.e. .p1, .p2, .p3 instead of .p2, .p4, .p5
-        } else if verify_discovered_parts(&discovered_paths) {
+        } else if discovered_paths.len() > 1
+            && verify_discovered_parts(&discovered_paths)
+        {
             // Add file name onto parent folder to reconstruct file into
             // If we don't use parent_folder here, the file will be recreated
             // in the working directory, instead of the file's directory
@@ -94,6 +103,7 @@ impl RunConfig {
                 part_paths: discovered_paths,
                 retain,
                 verbose,
+                dry_run,
             })
         } else {
             // Pretty up format a bit to make life easier for StickError
@@ -112,7 +122,7 @@ fn find_parts_in<P: AsRef<Path>>(root: P, search_stem: &OsStr) -> Vec<PathBuf> {
         .max_depth(1) // Search same folder
         .follow_links(true)
         // Zero padding file names in chop means sorting by file name here
-        // lets us get the parts in order, which is useful later for
+        // lets us get the parts in numerical order, which is useful later for
         // verifying we have a full run of them
         .sort_by_file_name()
         .into_iter()
@@ -140,6 +150,8 @@ fn find_parts_in<P: AsRef<Path>>(root: P, search_stem: &OsStr) -> Vec<PathBuf> {
         .collect()
 }
 
+// Check extensions indicate a complete set of parts
+// i.e. .p1, .p2, .p3 instead of .p2, .p4, .p5
 fn verify_discovered_parts(part_paths: &[PathBuf]) -> bool {
     part_paths
         .iter()
